@@ -201,7 +201,6 @@ R_PosInf <- Inf # nolint
 #' @seealso [eventTable()], [et()], [add.sampling()], [add.dosing()]
 #'
 #' @examples
-#'
 #' \donttest{
 #' # Step 1 - Create a model specification
 #' ode <- "
@@ -231,19 +230,20 @@ R_PosInf <- Inf # nolint
 #' # then after
 #'
 #' qd$add.sampling(0:24)
-#' qd$add.sampling(seq(from = 24+8, to = 5*24, by = 8))
+#' qd$add.sampling(seq(from = 24 + 8, to = 5 * 24, by = 8))
 #'
 #' # Step 3 - set starting parameter estimates and initial
 #' # values of the state
 #'
 #' theta <-
-#'     c(KA = .291, CL = 18.6,
-#'       V2 = 40.2, Q = 10.5, V3 = 297.0,
-#'       Kin = 1.0, Kout = 1.0, EC50 = 200.0)
+#'   c(
+#'     KA = .291, CL = 18.6,
+#'     V2 = 40.2, Q = 10.5, V3 = 297.0,
+#'     Kin = 1.0, Kout = 1.0, EC50 = 200.0
+#'   )
 #'
 #' # init state variable
-#' inits <- c(0, 0, 0, 1);
-#'
+#' inits <- c(0, 0, 0, 1)
 #' # Step 4 - Fit the model to the data
 #'
 #' qd.cp <- m1$solve(theta, events = qd, inits)
@@ -253,14 +253,11 @@ R_PosInf <- Inf # nolint
 #' # This returns a matrix.  Note that you can also
 #' # solve using name initial values. For example:
 #'
-#' inits <- c(eff = 1);
-#'
-#' qd.cp <- solve(m1, theta, events = qd, inits);
-#'
+#' inits <- c(eff = 1)
+#' qd.cp <- solve(m1, theta, events = qd, inits)
 #' print(qd.cp)
 #'
 #' plot(qd.cp)
-#'
 #' }
 #'
 #' @keywords models nonlinear
@@ -346,8 +343,7 @@ RxODE <- # nolint
         }
         model <- model$.model
         class(model) <- NULL
-      }
-      else if ((is(model, "function") || is(model, "call"))) {
+      } else if ((is(model, "function") || is(model, "call"))) {
         model <- deparse(body(model))[-1]
         model <- paste(model[-length(model)], collapse = "\n")
       }
@@ -416,18 +412,19 @@ RxODE <- # nolint
           .rx$.extraC(extraC)
           if (missing.modName) {
             .rxDll <- .rx$rxCompile(.mv,
-                                    debug = debug,
-                                    package = .(.env$package)
-                                    )
+              debug = debug,
+              package = .(.env$package)
+            )
           } else {
             .rxDll <- .rx$rxCompile(.mv,
-                                    dir = mdir,
-                                    debug = debug, modName = modName,
-                                    package = .(.env$package)
-                                    )
+              dir = mdir,
+              debug = debug, modName = modName,
+              package = .(.env$package)
+            )
           }
           .rxDll$linCmtM <- .(ifelse(exists(".linCmtM", .env),
-                                     get(".linCmtM", .env), NA))
+            get(".linCmtM", .env), NA
+          ))
           assign("rxDll", .rxDll, envir = .(.env))
           assign(".mv", .rxDll$modVars, envir = .(.env))
         })
@@ -1271,7 +1268,7 @@ rxCompile <- function(model, dir, prefix, force = FALSE, modName = NULL,
 }
 
 .pkg <- NULL
-#'@rdname rxCompile
+#' @rdname rxCompile
 #' @export
 rxCompile.rxModelVars <- function(model, # Model
                                   dir = NULL, # Directory
@@ -1298,7 +1295,7 @@ rxCompile.rxModelVars <- function(model, # Model
     if (file.exists(.dir)) {
       if (!file.exists(file.path(.dir, paste0(RxODE.md5, ".md5")))) {
         .malert("remove old RxODE dir {.file {.dir}}")
-        unlink(.dir, recursive=TRUE, force=TRUE)
+        unlink(.dir, recursive = TRUE, force = TRUE)
         .msuccess("done")
       }
     }
@@ -1406,14 +1403,16 @@ rxCompile.rxModelVars <- function(model, # Model
           .Call(
             `_RxODE_codegen`, .cFile, prefix, .libname,
             .trans["parsed_md5"], paste(.rxTimeId(.trans["parsed_md5"])),
-            .rxModelVarsLast)
+            .rxModelVarsLast
+          )
         } else {
           .libname <- gsub(.Platform$dynlib.ext, "", basename(.cDllFile))
           .libname <- c(.libname, .libname)
           .Call(
             `_RxODE_codegen`, .cFile, prefix, .libname,
             .trans["parsed_md5"], paste(.rxTimeId(.trans["parsed_md5"])),
-            .rxModelVarsLast)
+            .rxModelVarsLast
+          )
         }
         .defs <- ""
         .ret <- sprintf(
@@ -1444,7 +1443,7 @@ rxCompile.rxModelVars <- function(model, # Model
         })
         .stderr <- rawToChar(.out$stderr)
         if (!(all(.stderr == "") & length(.stderr) == 1)) {
-          message(paste(.stderr, sep="\n"))
+          message(paste(.stderr, sep = "\n"))
         }
         .badBuild <- function(msg, cSrc = TRUE) {
           msg <- gettext(msg)
