@@ -20,7 +20,7 @@ rxodeTest(
         d / dt(x0) <- 0
       })
 
-      ev <- et(1, id = 1:30000)
+      ev <- et(1, id = 1:70000)
 
       f <- warn1(rxSolve(rx, ev, c(a = 3, b = 5, c = 2), cores = 2))
 
@@ -172,7 +172,7 @@ rxodeTest(
         x1 <- rcauchy()
         x2 <- rxcauchy(a)
         x3 <- rcauchy(b, c)
-        d/dt(x0) <- 0
+        d / dt(x0) <- 0
       })
 
       ev <- et(1, id = 1:100)
@@ -398,7 +398,6 @@ rxodeTest(
     context("rbeta tests")
 
     test_that("rbeta tests", {
-
       rx <- RxODE({
         x1 <- rbeta(2, 5)
         x2 <- rxbeta(2, 2)
@@ -458,7 +457,7 @@ rxodeTest(
 
     test_that("rgeom tests", {
       rx <- RxODE({
-        #x1 <- rgeom(0.5)
+        # x1 <- rgeom(0.5)
         x2 <- rxgeom(0.1)
       })
 
@@ -467,7 +466,7 @@ rxodeTest(
       set.seed(1024)
       f <- warn1(rxSolve(rx, ev, cores = 2))
 
-      #expect_equal(median(f$x1), -ceiling(1 / log2(1 - 0.5)))
+      # expect_equal(median(f$x1), -ceiling(1 / log2(1 - 0.5)))
       expect_equal(median(f$x2), -ceiling(1 / log2(1 - 0.1)))
 
       ev <- et(1, id = 1:10)
@@ -647,7 +646,6 @@ rxodeTest(
     context("rweibull tests")
 
     test_that("rweibull tests", {
-
       rx <- RxODE({
         x1 <- rweibull(9, 0.5)
         x2 <- rxweibull(7.5)
@@ -707,16 +705,15 @@ rxodeTest(
     context("individual random number generation")
 
     test_that("individual random variable tests", {
-
       rx <- RxODE({
-        x0  <- rxnorm()
-        x1  <- rinorm(a)
-        x2  <- rinorm(b, c)
-        x3  <- rinorm()
-        x4  <- rinormV()
-        x5  <- rinormV(a)
-        x6  <- rinormV(b, c)
-        x7  <- ricauchy()
+        x0 <- rxnorm()
+        x1 <- rinorm(a)
+        x2 <- rinorm(b, c)
+        x3 <- rinorm()
+        x4 <- rinormV()
+        x5 <- rinormV(a)
+        x6 <- rinormV(b, c)
+        x7 <- ricauchy()
         x8 <- ricauchy(a)
         x9 <- ricauchy(b, c)
         x10 <- richisq(15)
@@ -732,11 +729,11 @@ rxodeTest(
         x20 <- riweibull(7.5)
         ## int, likely to repeat
         x21 <- ripois(1)
-        x22 <- ribeta(2, 5) ##?
+        x22 <- ribeta(2, 5) ## ?
         x23 <- rigeom(0.5)
         x24 <- ribinom(10, 0.5)
         ##
-        d/dt(xx) <- 0
+        d / dt(xx) <- 0
       })
 
       set.seed(10)
@@ -754,14 +751,14 @@ rxodeTest(
       }
 
       rx <- RxODE({
-        x0  <- rxnorm()
-        x1  <- rinorm(a)
-        x2  <- rinorm(b, c)
-        x3  <- rinorm()
-        x4  <- rinormV()
-        x5  <- rinormV(a)
-        x6  <- rinormV(b, c)
-        x7  <- ricauchy()
+        x0 <- rxnorm()
+        x1 <- rinorm(a)
+        x2 <- rinorm(b, c)
+        x3 <- rinorm()
+        x4 <- rinormV()
+        x5 <- rinormV(a)
+        x6 <- rinormV(b, c)
+        x7 <- ricauchy()
         x8 <- ricauchy(a)
         x9 <- ricauchy(b, c)
         x10 <- richisq(15)
@@ -777,7 +774,7 @@ rxodeTest(
         x20 <- riweibull(7.5)
         ## int, likely to repeat
         x21 <- ripois(1)
-        x22 <- ribeta(2, 5) ##?
+        x22 <- ribeta(2, 5) ## ?
         x23 <- rigeom(0.5)
         x24 <- ribinom(10, 0.5)
         ##
@@ -802,29 +799,29 @@ rxodeTest(
     test_that("simeps", {
       rx1 <- RxODE({
         c <- 0 + err
-        i = 0
+        i <- 0
       })
 
       e <- et(0, 10)
 
       set.seed(10)
-      f1 <- rxSolve(rx1, e, sigma=lotri(err ~ 1))
+      f1 <- rxSolve(rx1, e, sigma = lotri(err ~ 1))
 
       expect_true(f1$c[1] != 0)
 
       rx <- RxODE({
         c <- 0 + err
-        i = 0
+        i <- 0
         while (c < 0) {
           simeps()
           c <- 0 + err
-          i = i + 1
+          i <- i + 1
           if (i > 10) break
         }
       })
 
       set.seed(10)
-      f2 <- rxSolve(rx, e, sigma=lotri(err ~ 1))
+      f2 <- rxSolve(rx, e, sigma = lotri(err ~ 1))
 
       expect_true(f2$c[1] != 0)
 
@@ -834,34 +831,34 @@ rxodeTest(
 
       f3 <- f2[f2$i == 0, c("time", "c")]
 
-      f3 <- merge(f1, f3, by="time")
+      f3 <- merge(f1, f3, by = "time")
 
       ## If the condition is already satisfied, it should keep the originally simulated values
       expect_equal(f3$c.x, f3$c.y)
 
 
       set.seed(10)
-      f1 <- rxSolve(rx, e, sigma=lotri(err ~ 1), nStud=3)
+      f1 <- rxSolve(rx, e, sigma = lotri(err ~ 1), nStud = 3)
 
       expect_true(all(f1$c > 0))
 
       expect_true(f1$c[1] != 0)
 
       set.seed(10)
-      f2 <- rxSolve(rx1, e, sigma=lotri(err ~ 1), nStud=3)
+      f2 <- rxSolve(rx1, e, sigma = lotri(err ~ 1), nStud = 3)
 
       expect_false(all(f2$c > 0))
 
       expect_true(f2$c[1] != 0)
 
-      f3 <- merge(f1, f2, by=c("sim.id", "time"))
+      f3 <- merge(f1, f2, by = c("sim.id", "time"))
 
       f3 <- f3[f3$i == 0, ]
 
       expect_equal(f3$c.x, f3$c.y)
 
       set.seed(10)
-      f1 <- rxSolve(rx, e, sigma=lotri(err ~ 1), nStud=3, dfObs=100)
+      f1 <- rxSolve(rx, e, sigma = lotri(err ~ 1), nStud = 3, dfObs = 100)
 
       expect_true(all(f1$c > 0))
 
@@ -869,13 +866,13 @@ rxodeTest(
 
 
       set.seed(10)
-      f2 <- rxSolve(rx1, e, sigma=lotri(err ~ 1), nStud=3, dfObs=100)
+      f2 <- rxSolve(rx1, e, sigma = lotri(err ~ 1), nStud = 3, dfObs = 100)
 
       expect_false(all(f2$c > 0))
 
       expect_true(f2$c[1] != 0)
 
-      f3b <- merge(f1, f2, by=c("sim.id", "time"))
+      f3b <- merge(f1, f2, by = c("sim.id", "time"))
 
       f3b <- f3b[f3b$i == 0, ]
 
@@ -885,39 +882,37 @@ rxodeTest(
       expect_false(identical(f3b$c.y, f3$c.y))
 
       ## Check to make sure that this only accesses the
-      f1 <- rxSolve(rx, e, sigma=lotri(err ~ 1), nStud=3)
+      f1 <- rxSolve(rx, e, sigma = lotri(err ~ 1), nStud = 3)
 
       expect_true(all(f1$c > 0))
 
       expect_true(f1$c[1] != 0)
-
     })
 
     context("simeta()")
 
     test_that("simeta", {
-
       rx <- RxODE({
         wt <- 70 * exp(eta.wt)
         i <- 0
-        while((wt < 60) || (wt > 80)) {
+        while ((wt < 60) || (wt > 80)) {
           i <- i + 1
-          if(i > 100) break
+          if (i > 100) break
           simeta()
-          wt <- 70*exp(eta.wt)
+          wt <- 70 * exp(eta.wt)
         }
       })
 
-      e <- et(1:2, id=1:4)
+      e <- et(1:2, id = 1:4)
 
-      f <- rxSolve(rx, e, omega=lotri(eta.wt ~ 0.1 ^ 2))
+      f <- rxSolve(rx, e, omega = lotri(eta.wt ~ 0.1^2))
 
       expect_true(all(f$wt > 60))
       expect_true(all(f$wt < 80))
 
       expect_equal(length(unique(f$wt)), 4)
 
-      f <- rxSolve(rx, e, omega=lotri(eta.wt ~ 0.5 ^ 2), nStud=10)
+      f <- rxSolve(rx, e, omega = lotri(eta.wt ~ 0.5^2), nStud = 10)
 
       expect_true(all(f$wt > 60))
       expect_true(all(f$wt < 80))
@@ -925,49 +920,46 @@ rxodeTest(
       expect_equal(length(unique(f$wt)), 4 * 10)
 
       ## this one should work
-      f <- rxSolve(rx, e, omega=lotri(eta.wt ~ 0.5 ^ 2), nStud=3, dfSub=40)
+      f <- rxSolve(rx, e, omega = lotri(eta.wt ~ 0.5^2), nStud = 3, dfSub = 40)
 
       expect_true(all(f$wt > 60))
       expect_true(all(f$wt < 80))
 
       expect_equal(length(unique(f$wt)), 4 * 3)
-
-
     })
 
     context("r exports")
 
     test_that("random variables work in R alone", {
-
       set.seed(1024)
 
       expect_true(is.numeric(rxnormV()))
 
       expect_true(is.numeric(rxcauchy()))
 
-      p <- rxpois(2, n=30000)
+      p <- rxpois(2, n = 30000)
       expect_equal(mean(p), 2, tol = 0.01)
       expect_equal(sd(p), sqrt(2), tol = 0.01)
 
-      r <- rxt(15, n=30000)
+      r <- rxt(15, n = 30000)
       expect_equal(mean(r), 0, tol = 0.1)
       expect_equal(sd(r), sqrt(15 / (15 - 2)), tol = 0.1)
 
-      r <- rxbinom(4, 0.5, n=30000)
+      r <- rxbinom(4, 0.5, n = 30000)
       expect_equal(max(r), 4)
       expect_equal(min(r), 0)
       expect_equal(mean(r), 4 * 0.5, tol = 1e-2)
       expect_equal(sd(r), sqrt(4 * 0.5 * 0.5), tol = 1e-2)
 
-      chi <- rxchisq(15, n=30000)
+      chi <- rxchisq(15, n = 30000)
       expect_equal(mean(chi), 15, tol = 0.1)
       expect_equal(sd(chi), sqrt(2 * 15), tol = 0.1)
 
-      xp <- rxexp(0.5, n=30000)
+      xp <- rxexp(0.5, n = 30000)
       expect_equal(mean(xp), 2, tol = 0.1)
       expect_equal(sd(xp), sqrt(1 / (0.5 * 0.5)), tol = 0.1)
 
-      f <- rxf(30, 40, n=30000)
+      f <- rxf(30, 40, n = 30000)
 
       sf <- function(d1, d2) {
         sqrt((2 * d2^2 * (d1 + d2 - 2)) / (d1 * (d2 - 2)^2 * (d2 - 4)))
@@ -980,7 +972,7 @@ rxodeTest(
       expect_equal(mean(f), mf(40), tol = 0.01)
       expect_equal(sd(f), sf(30, 40), tol = 0.01)
 
-      x2 <- rxgamma(7.5, n=30000)
+      x2 <- rxgamma(7.5, n = 30000)
 
       sgamma <- function(k, theta = 1) {
         sqrt(k / (theta^2))
@@ -988,7 +980,7 @@ rxodeTest(
 
       ## expect_equal(sd(x2), sgamma(7.5), tol = 0.01)
 
-      x2 <- rxbeta(2, 2, n=30000)
+      x2 <- rxbeta(2, 2, n = 30000)
 
       mbeta <- function(a, b) {
         return(a / (a + b))
@@ -1001,21 +993,21 @@ rxodeTest(
       expect_equal(mean(x2), mbeta(2, 2), tol = 0.01)
       expect_equal(sd(x2), sbeta(2, 2), tol = 0.01)
 
-      x2 <- rxgeom(0.1, n=30000)
+      x2 <- rxgeom(0.1, n = 30000)
 
       expect_equal(median(x2), -ceiling(1 / log2(1 - 0.1)))
 
-      x2 <- rxpois(2, n=30000)
+      x2 <- rxpois(2, n = 30000)
 
       expect_equal(mean(x2), 2, tol = 0.01)
       expect_equal(sd(x2), sqrt(2), tol = 0.01)
 
-      x2 <- rxunif(0.5, n=30000)
+      x2 <- rxunif(0.5, n = 30000)
 
       expect_equal(mean(x2), 0.5 * (0.5 + 1), tol = 1e-2)
       expect_equal(sd(x2), sqrt((1 - 0.5)^2 / 12), tol = 1e-2)
 
-      x2 <- rxweibull(7.5, n=30000)
+      x2 <- rxweibull(7.5, n = 30000)
 
       mweibull <- function(shape, scale = 1) {
         lambda <- scale
@@ -1032,8 +1024,6 @@ rxodeTest(
 
       expect_equal(mean(x2), mweibull(7.5), tol = 0.01)
       expect_equal(sd(x2), sweibull(7.5), tol = 0.01)
-
-
     })
   },
   test = "norm"
